@@ -307,8 +307,10 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
 //
 void Prefpanel::shadeLight(void)
 {
-    QColorDialog::setCustomColor(0, m_pLight->rgb());
-    QColorDialog::setCustomColor(1, m_pDark->rgb());
+    QColorDialog::setCustomColor(0, this->getRevlight()->rgb());
+    QColorDialog::setCustomColor(1, this->getRevdark()->rgb());
+    QColorDialog::setCustomColor(2, this->getAltlight()->rgb());
+    QColorDialog::setCustomColor(3, this->getAltdark()->rgb());
     QColor Colortemp = QColorDialog::getColor(*m_pLight);
     if (Colortemp.isValid()) {
         delete m_pLight;
