@@ -85,7 +85,6 @@ Reportpanel::Reportpanel(TiTable *pTable, Preferences *pPreferences,
 
     // Store matrix and prefs members
     m_pReptable = pTable;
-//    m_pReptable->sortColumn(TITRAQ_IDXDATE, true, true);
     m_pReprefs  = pPreferences;
     m_pPrinter  = new QPrinter;
 
@@ -104,24 +103,27 @@ Reportpanel::Reportpanel(TiTable *pTable, Preferences *pPreferences,
     m_pBrowser->setReadOnly(true);
     m_pBrowser->setFont(QFont("Courier", 10));
     m_pFormlay->addWidget(m_pBrowser);
+    m_pFormlay->addSpacing(6);
     m_pFormlay->addLayout(m_pToolay);
+    m_pFormlay->addSpacing(6);
     m_pFormlay->addLayout(m_pPushlay);
 
     // Tool button suite
     m_pWeekmonthgroup = new QButtonGroup(this, "Weekmonthgroup");
     m_pWeekmonthgroup->setColumnLayout(0, Qt::Horizontal);
+    m_pWeekmonthgroup->layout()->setSpacing(11);
+    m_pWeekmonthgroup->layout()->setMargin(0);
     m_pWeekmonthlay = new QHBoxLayout(m_pWeekmonthgroup->layout());
-    m_pWeekmonthlay->setSpacing(11);
-    m_pWeekmonthlay->setMargin(0);
-    m_pWeekmonthlay->setAlignment(Qt::AlignTop);
     m_pWeekmonthgroup->setFrameShape(QFrame::NoFrame);
     m_pWeekmonthgroup->setExclusive(true);
     m_pWeeklybutt = new QToolButton(m_pWeekmonthgroup, "Weeklybutton");
-    m_pWeeklybutt->setPaletteBackgroundColor(QColor(198, 196, 186));
+//    m_pWeeklybutt->setPaletteBackgroundColor(QColor(198, 196, 186));
+    m_pWeeklybutt->setFocusPolicy(QWidget::TabFocus);
     m_pWeeklybutt->setCursor(QCursor(13));
     m_pWeeklybutt->setToggleButton(true);
     m_pMonthlybutt = new QToolButton(m_pWeekmonthgroup, "Monthlybutton");
-    m_pMonthlybutt->setPaletteBackgroundColor(QColor(198, 196, 186));
+//    m_pMonthlybutt->setPaletteBackgroundColor(QColor(198, 196, 186));
+    m_pMonthlybutt->setFocusPolicy(QWidget::TabFocus);
     m_pMonthlybutt->setCursor(QCursor(13));
     m_pMonthlybutt->setToggleButton(true);
 
@@ -170,16 +172,16 @@ Reportpanel::Reportpanel(TiTable *pTable, Preferences *pPreferences,
     m_pSavebutt = new QPushButton(this, "Savebutton");
     m_pSavebutt->setPaletteBackgroundColor(QColor(202, 194, 182));
     m_pSavebutt->setCursor(QCursor(13));
-    m_pDismissbutt = new QPushButton(this, "Dismissbutton");
-    m_pDismissbutt->setPaletteBackgroundColor(QColor(198, 196, 186));
-    m_pDismissbutt->setCursor(QCursor(13));
-    m_pDismissbutt->setDefault(true);
     m_pPrintbutt = new QPushButton(this, "Printbutton");
     m_pPrintbutt->setPaletteBackgroundColor(QColor(198, 196, 186));
     m_pPrintbutt->setCursor(QCursor(13));
 #ifdef QT_NO_PRINTER
     m_pPrintbutt->setEnabled(false);
 #endif
+    m_pDismissbutt = new QPushButton(this, "Dismissbutton");
+    m_pDismissbutt->setPaletteBackgroundColor(QColor(198, 196, 186));
+    m_pDismissbutt->setCursor(QCursor(13));
+    m_pDismissbutt->setDefault(true);
     m_pPushlay->addWidget(m_pSavebutt);
     m_pPushlay->addWidget(m_pPrintbutt);
     m_pPushlay->addWidget(m_pDismissbutt);
@@ -187,9 +189,9 @@ Reportpanel::Reportpanel(TiTable *pTable, Preferences *pPreferences,
     // Connect signals to slots, accept() and reject() are Qt implicit
     connect(m_pWeeklybutt, SIGNAL(clicked(void)), SLOT(reportWeeks(void)));
     connect(m_pMonthlybutt, SIGNAL(clicked(void)), SLOT(reportMonths(void)));
-    connect(m_pDismissbutt, SIGNAL(clicked(void)), SLOT(accept(void)));
     connect(m_pSavebutt, SIGNAL(clicked(void)), SLOT(saveReport(void)));
     connect(m_pPrintbutt, SIGNAL(clicked(void)), SLOT(printReport(void)));
+    connect(m_pDismissbutt, SIGNAL(clicked(void)), SLOT(accept(void)));
     this->resize(QSize(464, 332).expandedTo(minimumSizeHint()));
     this->textChange();
 }
@@ -739,15 +741,15 @@ void Reportpanel::textChange(void)
     this->setCaption(trUtf8("AS local report", "Local report using weekly or monthly data."));
 
     // Top level push buttons associated with accept and save slots
-    m_pDismissbutt->setText(trUtf8("Dismiss", "Comment for Dismissbutton"));
-    QToolTip::add(m_pDismissbutt, trUtf8("Closes the report panel", "Comment for tooltip Dismissbutton"));
-    QWhatsThis::add(m_pDismissbutt, trUtf8("The dismiss button dismisses the report panel", "Comment for whatsThis Dismissbutton"));
     m_pSavebutt->setText(trUtf8("Save", "Comment for Savebutton"));
     QToolTip::add(m_pSavebutt, trUtf8("Saves the report text", "Comment for tooltip Savebutton"));
     QWhatsThis::add(m_pSavebutt, trUtf8("The save button saves the report text to a file", "Comment for whatsThis Savebutton"));
     m_pPrintbutt->setText(trUtf8("Print", "Comment for Printbutton"));
     QToolTip::add(m_pPrintbutt, trUtf8("Print the report text", "Comment for tooltip Printbutton"));
     QWhatsThis::add(m_pPrintbutt, trUtf8("The print button prints the report text to a file", "Comment for whatsThis Printbutton"));
+    m_pDismissbutt->setText(trUtf8("Dismiss", "Comment for Dismissbutton"));
+    QToolTip::add(m_pDismissbutt, trUtf8("Closes the report panel", "Comment for tooltip Dismissbutton"));
+    QWhatsThis::add(m_pDismissbutt, trUtf8("The dismiss button dismisses the report panel", "Comment for whatsThis Dismissbutton"));
 
     // Inner tool buttons for new local report generation
     m_pWeeklybutt->setText(trUtf8("Weekly", "Comment for Weeklybutt"));
