@@ -220,6 +220,8 @@ void Titraqform::addEntry(int nRows)
 
     m_pMaintable->setUpdatesEnabled(true);  // Turn updates back on
     m_pMaintable->repaintContents(true);    // Do a general repaint of table
+    m_pMaintable->ensureCellVisible(m_pMaintable->currentRow() + nTotal - 1, m_pMaintable->currentColumn());
+    m_pMaintable->ensureCellVisible(m_pMaintable->currentRow(), m_pMaintable->currentColumn());
 
     // In case we added the first and only row entry,
     // do post state adjustments like icon undimming
